@@ -27,7 +27,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '1.045';
+our $VERSION = '1.047';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -104,7 +104,7 @@ __END__
 
 =head1 NAME
 
-Gnome2::GConf - Perl wrappers for the GConf configuration engine.
+Gnome2::GConf - (DEPRECATED) Perl wrappers for the GConf configuration engine.
 
 =head1 SYNOPSIS
 
@@ -147,11 +147,57 @@ Gnome2::GConf - Perl wrappers for the GConf configuration engine.
 
 =head1 ABSTRACT
 
-Perl bindings to the 2.2 series of the GConf configuration engine
+(DEPRECATED) Perl bindings to the 2.2 series of the GConf configuration engine
 libraries, for use with gtk2-perl.
 
 =head1 DESCRIPTION
 
+B<NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE>
+
+This module has been deprecated by the Gtk-Perl project.  This means that the
+module will no longer be updated with security patches, bug fixes, or when
+changes are made in the Perl ABI.  The Git repo for this module has been
+archived (made read-only), it will no longer possible to submit new commits to
+it.  You are more than welcome to ask about this module on the Gtk-Perl
+mailing list, but our priorities going forward will be maintaining Gtk-Perl
+modules that are supported and maintained upstream; this module is neither.
+
+Since this module is licensed under the LGPL v2, you may also fork this
+module, if you wish, but you will need to use a different name for it on CPAN,
+and the Gtk-Perl team requests that you use your own resources (mailing list,
+Git repos, bug trackers, etc.) to maintain your fork going forward.
+
+=over
+
+=item *
+
+Perl URL: https://gitlab.gnome.org/GNOME/perl-gnome2-gconf
+
+=item *
+
+Upstream URL: https://gitlab.gnome.org/Archive/gconf
+
+=item *
+
+Last upstream version: 3.2.6
+
+=item *
+
+Last upstream release date: 2013-01-21
+
+=item *
+
+Migration path for this module: Glib::IO::Settings
+
+=item *
+
+Migration module URL: https://metacpan.org/pod/Glib::IO
+
+=back
+
+B<NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE>
+
+
 This module allows you to use the GConf configuration system in order
 to store/retrieve the configuration of an application.  The GConf
 system is a powerful configuration manager based on a user daemon that
